These are the nexus files needed for the unit tests.

HIFI00180594.nxs: real single period data
HIFI00183810.nxs: real multiperiod data

The following are nexus files generated by MuonDataLib.
These are used to test the file writers.
It is important that when these files are updated they are tested directly

HIFI42.nxs: saved single period data, only works with Wimda, no sample logs
HIFI51.nxs: saved multiperiod data, only works with Wimda, no sample logs
